# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/btravel/staffs/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/btravel/staffs/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Btravel\\Staffs\\": "packages/btravel/staffs/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Btravel\Staffs\Providers\StaffsServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Staffs'  => Btravel\Staffs\Facades\Staffs::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Btravel\\StaffsTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Btravel\Staffs\Providers\StaffsServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Btravel\Staffs\Providers\StaffsServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Btravel\Staffs\Providers\StaffsServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/staffs/{modulename}

**User**

    http://path-to-route-folder/user/staffs/{modulename}

**Public**

    http://path-to-route-folder/staffs


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/staffs/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/staffs/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/staffs/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/staffs/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/staffs/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/staffs/{modulename}/{slug}
    METHOD: GET