<?php

namespace Btravel\Staffs\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Staffs\Models\Staff;

class StaffPolicy
{

    /**
     * Determine if the given user can view the staff.
     *
     * @param UserPolicy $user
     * @param Staff $staff
     *
     * @return bool
     */
    public function view(UserPolicy $user, Staff $staff)
    {
        if ($user->canDo('staffs.staff.view') && $user->isAdmin()) {
            return true;
        }

        return $staff->user_id == user_id() && $staff->user_type == user_type();
    }

    /**
     * Determine if the given user can create a staff.
     *
     * @param UserPolicy $user
     * @param Staff $staff
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('staffs.staff.create');
    }

    /**
     * Determine if the given user can update the given staff.
     *
     * @param UserPolicy $user
     * @param Staff $staff
     *
     * @return bool
     */
    public function update(UserPolicy $user, Staff $staff)
    {
        if ($user->canDo('staffs.staff.edit') && $user->isAdmin()) {
            return true;
        }

        return $staff->user_id == user_id() && $staff->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given staff.
     *
     * @param UserPolicy $user
     * @param Staff $staff
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Staff $staff)
    {
        return $staff->user_id == user_id() && $staff->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given staff.
     *
     * @param UserPolicy $user
     * @param Staff $staff
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Staff $staff)
    {
        if ($user->canDo('staffs.staff.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given staff.
     *
     * @param UserPolicy $user
     * @param Staff $staff
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Staff $staff)
    {
        if ($user->canDo('staffs.staff.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
